@@ -176,6 +176,9 @@ bool XkbHelper::initializeKeyboardLayouts(KeyboardConfig& config)
 
 	if( ! setxkbmapCommandArguments.isEmpty() ) {
 		return runConfigLayoutCommand(setxkbmapCommandArguments);
+		if( config.configureLayouts ) {
+			X11Helper::setDefaultLayout();
+		}
 	}
 	return false;
 }
