@@ -742,9 +742,13 @@ static const char def_session2[] =
 "[ -f /etc/xprofile ] && . /etc/xprofile\n"
 "[ -f $HOME/.xprofile ] && . $HOME/.xprofile\n"
 "\n"
-"for i in /etc/X11/Xresources/*; do\n"
-"  [ -f $i ] && xrdb -merge $i\n"
-"done\n"
+"if [ -d /etc/X11/Xresources ]; then\n"
+"  for i in /etc/X11/Xresources/*; do\n"
+"    [ -f $i ] && xrdb -merge $i\n"
+"  done\n"
+"elif [ -f /etc/X11/Xresources ]; then\n"
+"  xrdb -merge /etc/X11/Xresources\n"
+"fi\n"
 "[ -f $HOME/.Xresources ] && xrdb -merge $HOME/.Xresources\n"
 "\n"
 "case $session in\n"
