@@ -313,6 +313,8 @@ KGVerify::start()
         } else {
             applyPreset();
         }
+        if (_isReserve)
+            timer.start(FULL_GREET_TO * SECONDS);
     }
     sockNot->setEnabled(true);
     running = true;
@@ -440,6 +442,10 @@ KGVerify::slotTimeout()
         else
             timer.start(1000);
         updateStatus();
+    } else if (_isReserve) {
+        // assert(ctx == Login && running);
+        abort();
+        ::exit(EX_RESERVE);
     } else {
         // assert(ctx == Login);
         isClear = true;
@@ -464,6 +470,8 @@ KGVerify::slotActivity()
     } else if (timeable) {
         // timed login is possible and thus scheduled. reschedule it.
         timer.start(TIMED_GREET_TO * SECONDS);
+    } else if (_isReserve) {
+        timer.start(FULL_GREET_TO * SECONDS);
     }
 }
 
@@ -979,6 +987,7 @@ KGVerify::init(const QStringList &plugins)
             continue;
         }
         debug("GreeterPlugin %s (%s) loaded\n", qPrintable(pg), plugin.info->name);
+        plugin.action = 0;
         greetPlugins.append(plugin);
       next:
         pluginList.append(i);
