@@ -123,7 +123,7 @@ class DesktopGridEffect
         int highlightedDesktop;
         Window input;
         bool keyboardGrab;
-        bool wasWindowMove, wasDesktopMove;
+        bool wasWindowMove, wasDesktopMove, isValidMove;
         EffectWindow* windowMove;
         QPoint windowMoveDiff;
         QPoint dragStartPos;
