@@ -1,6 +1,7 @@
 /*
  *   Copyright (C) 2007 Petri Damsten <damu@iki.fi>
  *   Copyright (C) 2008 Marco Martin <notmart@gmail.com>
+ *   Copyright (C) 2010 Michel Lafon-Puyo <michel.lafonpuyo@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Library General Public License version 2 as
@@ -18,7 +19,6 @@
  */
 
 #include "temperature.h"
-#include <Plasma/SignalPlotter>
 #include <Plasma/Meter>
 #include <Plasma/Containment>
 #include <Plasma/Theme>
@@ -28,6 +28,7 @@
 #include <QGraphicsLinearLayout>
 #include <QTimer>
 #include <cmath>
+#include "plotter.h"
 
 using namespace KUnitConversion;
 
@@ -39,7 +40,6 @@ Temperature::Temperature(QObject *parent, const QVariantList &args)
     setHasConfigurationInterface(true);
     resize(215 + 20 + 23, 109 + 20 + 25);
     setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
-    connect(Plasma::Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(themeChanged()));
     m_sourceTimer.setSingleShot(true);
     connect(&m_sourceTimer, SIGNAL(timeout()), this, SLOT(sourcesAdded()));
 }
@@ -54,10 +54,8 @@ void Temperature::init()
     setEngine(dataEngine("systemmonitor"));
     setTitle(i18n("Temperature"));
 
-    configChanged();
-    
     /* At the time this method is running, not all source may be connected. */
-    connect(engine(), SIGNAL(sourceAdded(QString)), this, SLOT(sourceAdded(const QString)));
+    connect(engine(), SIGNAL(sourceAdded(const QString&)), this, SLOT(sourceAdded(const QString&)));
     foreach (const QString& source, engine()->sources()) {
         sourceAdded(source);
     }
@@ -66,7 +64,9 @@ void Temperature::init()
 void Temperature::configChanged()
 {
     KConfigGroup cg = config();
-    setInterval(cg.readEntry("interval", 2.0) * 1000);
+    setInterval(cg.readEntry("interval", 2.0) * 1000.0);
+    setSources(cg.readEntry("temps", m_sources.mid(0, 5)));
+    connectToEngine();
 }
 
 void Temperature::sourceAdded(const QString& name)
@@ -82,9 +82,7 @@ void Temperature::sourceAdded(const QString& name)
 
 void Temperature::sourcesAdded()
 {
-    KConfigGroup cg = config();
-    setItems(cg.readEntry("temps", m_sources.mid(0, 5)));
-    connectToEngine();
+    configChanged();
 }
 
 void Temperature::createConfigurationInterface(KConfigDialog *parent)
@@ -100,7 +98,7 @@ void Temperature::createConfigurationInterface(KConfigDialog *parent)
         QStandardItem *item1 = new QStandardItem(temp);
         item1->setEditable(false);
         item1->setCheckable(true);
-        if (items().contains(temp)) {
+        if (sources().contains(temp)) {
             item1->setCheckState(Qt::Checked);
         }
         QStandardItem *item2 = new QStandardItem(temperatureTitle(temp));
@@ -111,7 +109,7 @@ void Temperature::createConfigurationInterface(KConfigDialog *parent)
     ui.treeView->resizeColumnToContents(0);
 
     ui.intervalSpinBox->setValue(interval() / 1000.0);
-    ui.intervalSpinBox->setSuffix(i18n("s"));
+    ui.intervalSpinBox->setSuffix(i18nc("second", " s"));
     parent->setButtons(KDialog::Ok | KDialog::Cancel | KDialog::Apply);
     parent->addPage(widget, i18n("Temperature"), "media-flash");
 
@@ -125,24 +123,23 @@ void Temperature::configAccepted()
     KConfigGroup cgGlobal = globalConfig();
     QStandardItem *parentItem = m_tempModel.invisibleRootItem();
 
-    clearItems();
+    clear();
+
     for (int i = 0; i < parentItem->rowCount(); ++i) {
         QStandardItem *item = parentItem->child(i, 0);
         if (item) {
             cgGlobal.writeEntry(item->text(),
                                 parentItem->child(i, 1)->text());
             if (item->checkState() == Qt::Checked) {
-                appendItem(item->text());
+                appendSource(item->text());
             }
         }
     }
-    cg.writeEntry("temps", items());
+    cg.writeEntry("temps", sources());
     uint interval = ui.intervalSpinBox->value();
     cg.writeEntry("interval", interval);
-    setInterval(interval * 1000.0);
 
     emit configNeedsSaving();
-    connectToEngine();
 }
 
 QString Temperature::temperatureTitle(const QString& source)
@@ -151,95 +148,40 @@ QString Temperature::temperatureTitle(const QString& source)
     return cg.readEntry(source, source.mid(source.lastIndexOf('/') + 1).replace('_',' '));
 }
 
-bool Temperature::addMeter(const QString& source)
+bool Temperature::addVisualization(const QString& source)
 {
     Plasma::DataEngine *engine = dataEngine("systemmonitor");
-    Plasma::DataEngine::Data data;
-    Plasma::Theme* theme = Plasma::Theme::defaultTheme();
 
     if (!engine) {
         return false;
     }
-    int min, max;
+
+    SM::Plotter *plotter = new SM::Plotter(this);
+    plotter->setTitle(temperatureTitle(source));
+    plotter->setAnalog(mode() != SM::Applet::Panel);
+
     if (KGlobal::locale()->measureSystem() == KLocale::Metric) {
-        min = 0;
-        max = 110;
+        plotter->setMinMax(0, 110);
+        plotter->setUnit(QString::fromUtf8("°C"));
     } else {
-        min = 32;
-        max = 230;
+        plotter->setMinMax(32, 230);
+        plotter->setUnit(QString::fromUtf8("°F"));
     }
-    data = engine->query(source);
-    QGraphicsLinearLayout *layout = new QGraphicsLinearLayout(Qt::Horizontal);
-    layout->setContentsMargins(3, 3, 3, 3);
-    layout->setSpacing(5);
-    QString title = temperatureTitle(source);
-
-    if (mode() != SM::Applet::Panel) {
-        Plasma::Meter *meter = new Plasma::Meter(this);
-        meter->setMeterType(Plasma::Meter::AnalogMeter);
-        if (mode() != SM::Applet::Panel) {
-            meter->setLabel(0, title);
-            meter->setLabelColor(0, theme->color(Plasma::Theme::TextColor));
-            meter->setLabel(1, QString());
-            meter->setLabelColor(1, QColor("#000"));
-            meter->setLabelAlignment(1, Qt::AlignCenter);
-            QFont font = theme->font(Plasma::Theme::DefaultFont);
-            font.setPointSize(7);
-            meter->setLabelFont(0, font);
-            meter->setLabelFont(1, font);
-        }
-        meter->setMinimum(min);
-        meter->setMaximum(max);
-        layout->addItem(meter);
-        appendMeter(source, meter);
-        appendKeepRatio(meter);
-        setMinimumWidth(24);
-    }
-    Plasma::SignalPlotter *plotter = new Plasma::SignalPlotter(this);
-    plotter->addPlot(adjustColor(theme->color(Plasma::Theme::TextColor), 40));
-    plotter->setThinFrame(false);
-    plotter->setShowLabels(false);
-    plotter->setShowTopBar(true);
-    plotter->setShowVerticalLines(false);
-    plotter->setShowHorizontalLines(false);
-    plotter->setTitle(title);
-    plotter->setUseAutoRange(false);
-    plotter->setVerticalRange(min, max);
-    plotter->setFontColor(theme->color(Plasma::Theme::TextColor));
-    QFont font = theme->font(Plasma::Theme::DefaultFont);
-    font.setPointSize(8);
-    plotter->setFont(font);
-    plotter->setSvgBackground("widgets/plot-background");
-    layout->addItem(plotter);
-    appendPlotter(source, plotter);
-    setRatioOrientation(Qt::Horizontal);
-    mainLayout()->addItem(layout);
+    appendVisualization(source, plotter);
 
+    Plasma::DataEngine::Data data = engine->query(source);
     dataUpdated(source, data);
     setPreferredItemHeight(80);
     return true;
 }
 
-void Temperature::themeChanged()
-{
-    Plasma::Theme* theme = Plasma::Theme::defaultTheme();
-    foreach (Plasma::Meter *w, meters()) {
-        w->setLabelColor(0, theme->color(Plasma::Theme::TextColor));
-        QFont font = theme->font(Plasma::Theme::DefaultFont);
-        font.setPointSize(7);
-        w->setLabelFont(0, font);
-        w->setLabelFont(1, font);
-    }
-}
-
 void Temperature::dataUpdated(const QString& source,
                               const Plasma::DataEngine::Data &data)
 {
-    if (!items().contains(source)) {
+    if (!sources().contains(source)) {
         return;
     }
-    Plasma::Meter *w = meters().value(source);
-    Plasma::SignalPlotter *plotter = plotters().value(source);
+    SM::Plotter *plotter = qobject_cast<SM::Plotter*>(visualization(source));
     QString temp;
     QString unit = data["units"].toString();
     double doubleValue = data["value"].toDouble();
@@ -252,19 +194,12 @@ void Temperature::dataUpdated(const QString& source,
     }
 
     value.round(1);
-    temp = value.toSymbolString();
-
-    if (w) {
-        w->setValue(doubleValue);
-        if (mode() != SM::Applet::Panel) {
-            w->setLabel(1, temp);
-        }
-    }
     if (plotter) {
-        plotter->addSample(QList<double>() << doubleValue);
-        setPlotterOverlayText(plotter, temp);
+        plotter->addSample(QList<double>() << value.number());
     }
 
+    temp = value.toSymbolString();
+
     if (mode() == SM::Applet::Panel) {
         setToolTip(source,
                    QString("<tr><td>%1</td><td>%2</td></tr>").arg(temperatureTitle(source)).arg(temp));
